Guardix class
Main entry point for the guardix plugin.
Use getSecurityStatus to check the security state of the device.
Constructors
- Guardix()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getSecurityStatus(
) → Future< DeviceSecurityStatus> - Returns the current DeviceSecurityStatus of the device.