MethodChannelGuardix class

The method channel implementation of GuardixPlatform.

Uses a MethodChannel to communicate with the native Android and iOS implementations.

Inheritance

Constructors

MethodChannelGuardix()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkMockLocation({bool strictMode = true}) Future<bool>
Checks mock location status with optional strict mode.
override
getSecurityStatus() Future<DeviceSecurityStatus>
Returns the current DeviceSecurityStatus from the native platform.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited