DeviceSecurityStatus class

Represents the security status of the current device.

Returned by Guardix.getSecurityStatus.

Constructors

DeviceSecurityStatus({required bool isDeveloperMode, required bool isEmulator, required bool isRootedOrJailbroken})
Creates a DeviceSecurityStatus instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isCompromised bool
Returns true if any security concern is detected.
no setter
isDeveloperMode bool
Whether developer mode or USB debugging is enabled.
final
isEmulator bool
Whether the app is running on an emulator or simulator.
final
isRootedOrJailbroken bool
Whether the device is rooted (Android) or jailbroken (iOS).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited