GuardixPlatform class abstract
The platform interface for the guardix plugin.
Platform implementations must extend this class.
- Inheritance
-
- Object
- PlatformInterface
- GuardixPlatform
- Implementers
Constructors
- GuardixPlatform()
- Constructs a GuardixPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSecurityStatus(
) → Future< DeviceSecurityStatus> - Returns the current DeviceSecurityStatus of the device.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ GuardixPlatform
-
The default instance of GuardixPlatform to use.
getter/setter pair